==> shiro-root-2.0.2-source-release.zip: shiro-root-2.0.2/README.md <==
[<img src="http://shiro.apache.org/images/apache-shiro-logo.png" align="right" />](http://shiro.apache.org)

[![Maven Central](https://img.shields.io/maven-central/v/org.apache.shiro/shiro-core)](https://central.sonatype.com/artifact/org.apache.shiro/shiro-core/)
[![Build Status](https://ci-builds.apache.org/buildStatus/icon?job=Shiro%2FShiro-all%2Fmain)](https://ci-builds.apache.org/job/Shiro/job/Shiro-all/job/main/)
[![OpenSSF Scorecard](https://api.securityscorecards.dev/projects/github.com/apache/shiro/badge)](https://api.securityscorecards.dev/projects/github.com/apache/shiro)
[![Reproducible Builds](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/jvm-repo-rebuild/reproducible-central/master/content/org/apache/shiro/badge.json)](https://github.com/jvm-repo-rebuild/reproducible-central/blob/master/content/org/apache/shiro/README.md)

Apache Shiro
============

[Apache Shiro](http://shiro.apache.org) is a powerful and easy-to-use Java security framework that performs authentication, authorization, cryptography, and session management. With Shiro’s easy-to-understand API, you can quickly and easily secure any application – from the smallest mobile applications to the largest web and enterprise applications.

Documentation and Examples
--------------------------
http://shiro.apache.org

Tutorials
---------
* [10 Minute Tutorial](http://shiro.apache.org/10-minute-tutorial.html)
* [Web Application](http://shiro.apache.org/webapp-tutorial.html) 

License
-------
[Apache License, Version 2.0](https://www.apache.org/licenses/LICENSE-2.0.txt)

==> shiro-root-2.0.4-source-release.zip: shiro-root-2.0.4/README.md <==
[<img src="http://shiro.apache.org/images/apache-shiro-logo.png" align="right" />](http://shiro.apache.org)

[![Maven Central](https://img.shields.io/maven-central/v/org.apache.shiro/shiro-core)](https://central.sonatype.com/artifact/org.apache.shiro/shiro-core/)
[![Build Status](https://ci-builds.apache.org/buildStatus/icon?job=Shiro%2FShiro-all%2Fmain)](https://ci-builds.apache.org/job/Shiro/job/Shiro-all/job/main/)
[![OpenSSF Scorecard](https://img.shields.io/ossf-scorecard/github.com/apache/shiro?style=plastic&label=openssf%20scorecard)](https://deps.dev/project/github/apache%2Fshiro)
[![Reproducible Builds](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/jvm-repo-rebuild/reproducible-central/master/content/org/apache/shiro/badge.json)](https://github.com/jvm-repo-rebuild/reproducible-central/blob/master/content/org/apache/shiro/README.md)

Apache Shiro
============

[Apache Shiro](http://shiro.apache.org) is a powerful and easy-to-use Java security framework that performs authentication, authorization, cryptography, and session management. With Shiro’s easy-to-understand API, you can quickly and easily secure any application – from the smallest mobile applications to the largest web and enterprise applications.

Documentation and Examples
--------------------------
http://shiro.apache.org

Tutorials
---------
* [10 Minute Tutorial](http://shiro.apache.org/10-minute-tutorial.html)
* [Web Application](http://shiro.apache.org/webapp-tutorial.html) 

License
-------
[Apache License, Version 2.0](https://www.apache.org/licenses/LICENSE-2.0.txt)
